# Changelog

## 0.13.1 (2026-02-27)

Full Changelog: [v0.13.0...v0.13.1](https://github.com/CaseMark/casedev-python/compare/v0.13.0...v0.13.1)

### Chores

* **ci:** bump uv version ([e739162](https://github.com/CaseMark/casedev-python/commit/e73916268b1604b6b96e894fa0df2da41608ce57))

## 0.13.0 (2026-02-26)

Full Changelog: [v0.12.6...v0.13.0](https://github.com/CaseMark/casedev-python/compare/v0.12.6...v0.13.0)

### Features

* **api:** api update ([3e84faf](https://github.com/CaseMark/casedev-python/commit/3e84fafb3536ed4097d29cf6b691198e4729c3b4))

## 0.12.6 (2026-02-25)

Full Changelog: [v0.12.5...v0.12.6](https://github.com/CaseMark/casedev-python/compare/v0.12.5...v0.12.6)

### Chores

* **internal:** make `test_proxy_environment_variables` more resilient to env ([574334a](https://github.com/CaseMark/casedev-python/commit/574334a89b19baa8fcbb72100c2fc033f2a3c80c))

## 0.12.5 (2026-02-24)

Full Changelog: [v0.12.4...v0.12.5](https://github.com/CaseMark/casedev-python/compare/v0.12.4...v0.12.5)

### Bug Fixes

* prevent duplicate Slack alerts from release-please branches ([5baa9ee](https://github.com/CaseMark/casedev-python/commit/5baa9ee4572bed65b873e4a0e5d7c1e5c0f694f9))

## 0.12.4 (2026-02-24)

Full Changelog: [v0.12.3...v0.12.4](https://github.com/CaseMark/casedev-python/compare/v0.12.3...v0.12.4)

### Chores

* **internal:** make `test_proxy_environment_variables` more resilient ([926dcd4](https://github.com/CaseMark/casedev-python/commit/926dcd48c22e1cf94f3894ed365df6898cb27c59))

## 0.12.3 (2026-02-24)

Full Changelog: [v0.12.2...v0.12.3](https://github.com/CaseMark/casedev-python/compare/v0.12.2...v0.12.3)

### Chores

* **internal:** add request options to SSE classes ([c06aa38](https://github.com/CaseMark/casedev-python/commit/c06aa386cdaa7d2aa51eaa088525c61e959844c4))

## 0.12.2 (2026-02-23)

Full Changelog: [v0.12.1...v0.12.2](https://github.com/CaseMark/casedev-python/compare/v0.12.1...v0.12.2)

### Bug Fixes

* only alert on CI failure for PRs targeting main ([7ad6c4b](https://github.com/CaseMark/casedev-python/commit/7ad6c4b62772ab94d3ca060d27f587eb7e5f8672))
* only alert Slack on CI failure for main branch ([0941a51](https://github.com/CaseMark/casedev-python/commit/0941a5150ba78f3661915378cfd10f7d2dd059b4))

## 0.12.1 (2026-02-23)

Full Changelog: [v0.12.0...v0.12.1](https://github.com/CaseMark/casedev-python/compare/v0.12.0...v0.12.1)

### Chores

* replace PR open Slack alert with CI failure alert ([ddb4311](https://github.com/CaseMark/casedev-python/commit/ddb4311f3e9dbd837e147278e74360c53edfc39f))

## 0.12.0 (2026-02-21)

Full Changelog: [v0.11.2...v0.12.0](https://github.com/CaseMark/casedev-python/compare/v0.11.2...v0.12.0)

### Features

* **api:** api update ([9e34f8a](https://github.com/CaseMark/casedev-python/commit/9e34f8a5dccba5cdb95c1f95208606a6a4a2f440))
* **api:** api update ([135dc3c](https://github.com/CaseMark/casedev-python/commit/135dc3cd51e46fe958d0065821432194c4879beb))

## 0.11.2 (2026-02-20)

Full Changelog: [v0.11.1...v0.11.2](https://github.com/CaseMark/casedev-python/compare/v0.11.1...v0.11.2)

## 0.11.1 (2026-02-20)

Full Changelog: [v0.11.0...v0.11.1](https://github.com/CaseMark/casedev-python/compare/v0.11.0...v0.11.1)

### Chores

* **internal:** remove mock server code ([85989d2](https://github.com/CaseMark/casedev-python/commit/85989d2beea17ba3b7cd73049f09fa0b40dde021))
* update mock server docs ([398b8ee](https://github.com/CaseMark/casedev-python/commit/398b8ee1872d14c12b605015dac7e234a5f6eb8b))

## 0.11.0 (2026-02-20)

Full Changelog: [v0.10.0...v0.11.0](https://github.com/CaseMark/casedev-python/compare/v0.10.0...v0.11.0)

### Features

* **api:** api update ([77773aa](https://github.com/CaseMark/casedev-python/commit/77773aa58e7a5b7296404f1a0cece53c7cbb4d92))

## 0.10.0 (2026-02-19)

Full Changelog: [v0.9.0...v0.10.0](https://github.com/CaseMark/casedev-python/compare/v0.9.0...v0.10.0)

### Features

* **api:** api update ([23dce42](https://github.com/CaseMark/casedev-python/commit/23dce421ed9fa4590d266fcf26a5b9fb77531a9e))
* **api:** api update ([683b41d](https://github.com/CaseMark/casedev-python/commit/683b41d26df92ecd58f95556eb45b5fe64567b1f))
* **api:** api update ([c001e00](https://github.com/CaseMark/casedev-python/commit/c001e001c708a0b0fc0fb4f5bfba401783883999))

## 0.9.0 (2026-02-14)

Full Changelog: [v0.8.1...v0.9.0](https://github.com/CaseMark/casedev-python/compare/v0.8.1...v0.9.0)

### Features

* **api:** api update ([9cc3c1f](https://github.com/CaseMark/casedev-python/commit/9cc3c1f3f1a1171f707c87c3eb6fad14ee2a8e91))

## 0.8.1 (2026-02-14)

Full Changelog: [v0.8.0...v0.8.1](https://github.com/CaseMark/casedev-python/compare/v0.8.0...v0.8.1)

### Bug Fixes

* resolve CI failures in smoke test integration ([9f166ff](https://github.com/CaseMark/casedev-python/commit/9f166ffdbdbe73ac5092a212070e11350ba3d9ff))


### Styles

* fix ruff isort import formatting in smoke tests ([e80a3f3](https://github.com/CaseMark/casedev-python/commit/e80a3f35b28539a307ccf6be344e862cfb18679e))

## 0.8.0 (2026-02-13)

Full Changelog: [v0.7.0...v0.8.0](https://github.com/CaseMark/casedev-python/compare/v0.7.0...v0.8.0)

### Features

* **api:** api update ([030d193](https://github.com/CaseMark/casedev-python/commit/030d193974713a91146ab6f1318fc940f44ff297))

## 0.7.0 (2026-02-13)

Full Changelog: [v0.6.1...v0.7.0](https://github.com/CaseMark/casedev-python/compare/v0.6.1...v0.7.0)

### Features

* **api:** api update ([e7ffc76](https://github.com/CaseMark/casedev-python/commit/e7ffc76d19f6ef07eb8dede8d5e447ec120e9e9b))
* **api:** api update ([a4f3ec4](https://github.com/CaseMark/casedev-python/commit/a4f3ec4a63d720f1609724986690da1570bb9ad2))
* **api:** api update ([1302637](https://github.com/CaseMark/casedev-python/commit/1302637edebcb3969708cd36ad4b2f55c81d4fae))


### Chores

* format all `api.md` files ([0a14fe4](https://github.com/CaseMark/casedev-python/commit/0a14fe431acd3a9a034d51d15448ed8013ef347e))
* **internal:** fix lint error on Python 3.14 ([949df45](https://github.com/CaseMark/casedev-python/commit/949df458de6bcb8b4f6a12a1ad9128d9b8af4250))

## 0.6.1 (2026-02-10)

Full Changelog: [v0.6.0...v0.6.1](https://github.com/CaseMark/casedev-python/compare/v0.6.0...v0.6.1)

### Chores

* **internal:** bump dependencies ([983f265](https://github.com/CaseMark/casedev-python/commit/983f265316c1ca4fbd5dd414f574abc5a62be27b))

## 0.6.0 (2026-02-10)

Full Changelog: [v0.5.0...v0.6.0](https://github.com/CaseMark/casedev-python/compare/v0.5.0...v0.6.0)

### Features

* **api:** api update ([36cbc0c](https://github.com/CaseMark/casedev-python/commit/36cbc0cf466fd98fcf58b7a40a2b2080ad9b21f3))


### Chores

* update SDK settings ([4f246c4](https://github.com/CaseMark/casedev-python/commit/4f246c445acecc3553791855f9eb9b24a1423c00))

## 0.5.0 (2026-02-06)

Full Changelog: [v0.4.0...v0.5.0](https://github.com/CaseMark/casedev-python/compare/v0.4.0...v0.5.0)

### Features

* **api:** api update ([68cd352](https://github.com/CaseMark/casedev-python/commit/68cd352836fcab271ba9ae1b513b7d94c5d1a7c2))

## 0.4.0 (2026-02-04)

Full Changelog: [v0.3.0...v0.4.0](https://github.com/CaseMark/casedev-python/compare/v0.3.0...v0.4.0)

### Features

* **api:** api update ([d47d2e2](https://github.com/CaseMark/casedev-python/commit/d47d2e22941bbee814a3e7e99bb6ab611786c2b8))
* **api:** api update ([b5968ff](https://github.com/CaseMark/casedev-python/commit/b5968ff3ecf6faaa54dabdb1c369a98dccf16229))
* **api:** api update ([a1bfede](https://github.com/CaseMark/casedev-python/commit/a1bfedec986cfe7f79b569d0841f43befc230633))
* **api:** api update ([a740247](https://github.com/CaseMark/casedev-python/commit/a7402478c5ec609a514d125c3e8be3049fe687d2))

## 0.3.0 (2026-01-31)

Full Changelog: [v0.2.0...v0.3.0](https://github.com/CaseMark/casedev-python/compare/v0.2.0...v0.3.0)

### Features

* **api:** api update ([9552466](https://github.com/CaseMark/casedev-python/commit/95524660fc8d6bc6b4afbd3e881bf15e7378cfe0))
* **api:** api update ([e3f5b6b](https://github.com/CaseMark/casedev-python/commit/e3f5b6bcc11924a87716cbb6e99d39e0c0603f74))
* **api:** api update ([ab9ad93](https://github.com/CaseMark/casedev-python/commit/ab9ad9365e44ec36f5ba3cb5c47436bcdcba095e))
* **api:** api update ([92d6d3e](https://github.com/CaseMark/casedev-python/commit/92d6d3e780ef1f21b3d5fb1839be1bb1973bdec9))
* **api:** api update ([c1ae1f0](https://github.com/CaseMark/casedev-python/commit/c1ae1f0f67d01c6131cea0a3cdfdd7b62430e57a))
* **client:** add custom JSON encoder for extended type support ([34a252e](https://github.com/CaseMark/casedev-python/commit/34a252ea9464e00bd27f8b12fcb027e283c095bd))

## 0.2.0 (2026-01-24)

Full Changelog: [v0.1.0...v0.2.0](https://github.com/CaseMark/casedev-python/compare/v0.1.0...v0.2.0)

### Features

* **api:** api update ([cb57987](https://github.com/CaseMark/casedev-python/commit/cb57987717857d312dd3a6c733eb3d64b40d874a))
* **api:** api update ([6f7ac9f](https://github.com/CaseMark/casedev-python/commit/6f7ac9f96595e35b20e6b7f33af36532a163a9a8))
* **api:** api update ([fea56de](https://github.com/CaseMark/casedev-python/commit/fea56ded1aaf613e112aca7b6a2d6ec0fe2275f3))
* **api:** api update ([237a3cc](https://github.com/CaseMark/casedev-python/commit/237a3cc7fe524e9becf35efb45edbd4e4676db1e))
* **api:** api update ([b56886e](https://github.com/CaseMark/casedev-python/commit/b56886ec5a36b297b6421e9bfa58589471efc0f3))
* **api:** api update ([266e6e0](https://github.com/CaseMark/casedev-python/commit/266e6e03886b8a962e1d233cefb1a4e799689077))
* **api:** api update ([b4fd0e1](https://github.com/CaseMark/casedev-python/commit/b4fd0e192591735cd313c2f8a2ebd4bb585f9a22))
* **api:** api update ([eff5344](https://github.com/CaseMark/casedev-python/commit/eff53445012586d2e33b0617108d15671a6557de))
* **api:** api update ([c39c859](https://github.com/CaseMark/casedev-python/commit/c39c859876d97500712f1dd6f071cf440b61077b))
* **api:** api update ([072926b](https://github.com/CaseMark/casedev-python/commit/072926ba2fc867216cd8a87dad7f4cb5ace4d851))
* **api:** api update ([4477cc4](https://github.com/CaseMark/casedev-python/commit/4477cc432fd5f46f4a4e9776b915bfa9e458fab4))
* **api:** api update ([06a0f2a](https://github.com/CaseMark/casedev-python/commit/06a0f2a30aecf7913bf0b34367348c83c6483d72))
* **api:** api update ([f662b55](https://github.com/CaseMark/casedev-python/commit/f662b5554f1df2769e0909083fa8f56ad47f113b))
* **api:** api update ([8ac179e](https://github.com/CaseMark/casedev-python/commit/8ac179eda3b6e3e94439777d9528e2fd32e4d84b))
* **api:** api update ([8289fd5](https://github.com/CaseMark/casedev-python/commit/8289fd58159c05d5a565de08f3dd08814df0890b))
* **client:** add support for binary request streaming ([7e76b57](https://github.com/CaseMark/casedev-python/commit/7e76b572106469ad4f4b910e0b45cce5ee68fcae))


### Bug Fixes

* **types:** allow pyright to infer TypedDict types within SequenceNotStr ([1176765](https://github.com/CaseMark/casedev-python/commit/117676502d91fa5f20073851bf074f508ade4e40))
* use async_to_httpx_files in patch method ([77d15e3](https://github.com/CaseMark/casedev-python/commit/77d15e35c394f535ecbe98d2f5b7c2cd4f151489))


### Chores

* add missing docstrings ([ed8538a](https://github.com/CaseMark/casedev-python/commit/ed8538a2830c45222529a3571053a5b3cbca184c))
* **ci:** upgrade `actions/github-script` ([8057dc0](https://github.com/CaseMark/casedev-python/commit/8057dc0a5ef3a91441aac335711c2934323aa87c))
* **internal:** add `--fix` argument to lint script ([d402a1a](https://github.com/CaseMark/casedev-python/commit/d402a1a46693b9c721b7e573ee1ec54584afca37))
* **internal:** add missing files argument to base client ([e45cbc5](https://github.com/CaseMark/casedev-python/commit/e45cbc54372e2d93a6b6ec58e8e546ed6bfad117))
* **internal:** update `actions/checkout` version ([483fb99](https://github.com/CaseMark/casedev-python/commit/483fb99d0c65ce7eba40870dddfa84c7fb86966d))
* speedup initial import ([8185ce9](https://github.com/CaseMark/casedev-python/commit/8185ce9973ce7076ae88aa2dcb7868450f9ea1b5))
* update SDK settings ([498643c](https://github.com/CaseMark/casedev-python/commit/498643c394fa4d9473e76475f025e3a9ab2562d8))


### Refactors

* **internal:** switch from rye to uv ([910f118](https://github.com/CaseMark/casedev-python/commit/910f11868c852a8d33422301ec80036081dcaf5d))

## 0.1.0 (2025-12-08)

Full Changelog: [v0.0.1...v0.1.0](https://github.com/CaseMark/casedev-python/compare/v0.0.1...v0.1.0)

### Features

* **api:** api update ([f016636](https://github.com/CaseMark/casedev-python/commit/f01663617b152a538b7ca668272be3dfcc3b0dc9))
* **api:** api update ([3966424](https://github.com/CaseMark/casedev-python/commit/3966424bf12ae7bd1c389fb18e85ec27fb784b4c))
* **api:** api update ([bdd8f5b](https://github.com/CaseMark/casedev-python/commit/bdd8f5b481346d6354609b4b09ebae8dbd71a9fc))
* **api:** api update ([8d0cbe9](https://github.com/CaseMark/casedev-python/commit/8d0cbe93ef8fb68e4895b064c7a5483b8d50dc2c))
* **api:** api update ([46a5bca](https://github.com/CaseMark/casedev-python/commit/46a5bcab1b018f33c1c45daf3584678fece36f3c))
* **api:** manual updates ([0857a27](https://github.com/CaseMark/casedev-python/commit/0857a27df9330ed223236f22b4c086146c15d1f8))
* **api:** manual updates ([eeb7830](https://github.com/CaseMark/casedev-python/commit/eeb7830cb058b1ef4be3c6edfefa1a33efe16f0e))
* **api:** manual updates ([7c7022f](https://github.com/CaseMark/casedev-python/commit/7c7022f6e7b5603b8e98f75fe102219f789ff3ba))


### Bug Fixes

* ensure streams are always closed ([b30b9ec](https://github.com/CaseMark/casedev-python/commit/b30b9ec808299da7d4bfade2a52b9a5529bf3d9a))


### Chores

* **deps:** mypy 1.18.1 has a regression, pin to 1.17 ([714ab77](https://github.com/CaseMark/casedev-python/commit/714ab7768f8895da8e0e6c56ceb506dd946d7e76))
* **docs:** use environment variables for authentication in code snippets ([f57c037](https://github.com/CaseMark/casedev-python/commit/f57c037c435e38d740180acdfa155252f610315e))
* update lockfile ([56cba77](https://github.com/CaseMark/casedev-python/commit/56cba77d5c25b33a5464120c58e648a44921b43c))
* update SDK settings ([0fb22b3](https://github.com/CaseMark/casedev-python/commit/0fb22b30b2bf11f50b8c7a23e020c3e51878f817))
